==> estateplat-common-1.2.4-20201111.090346-495-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltQlLqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltQlLq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltQlLqBdc extends QltQlLq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfldsyqxzdm;
    private String dfldsyqxzmc;
    private String dflzdm;
    private String dflzmc;
    private String dfqydm;
    private String dfqymc;
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlTransient
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlTransient
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlTransient
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFLDSYQXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfldsyqxzdm() {
        return dfldsyqxzdm;
    }

    public void setDfldsyqxzdm(String dfldsyqxzdm) {
        this.dfldsyqxzdm = dfldsyqxzdm;
    }
    @XmlTransient
    public String getDfldsyqxzmc() {
        return dfldsyqxzmc;
    }

    public void setDfldsyqxzmc(String dfldsyqxzmc) {
        this.dfldsyqxzmc = dfldsyqxzmc;
    }
    @XmlAttribute(
            name = "DFLZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDflzdm() {
        return dflzdm;
    }

    public void setDflzdm(String dflzdm) {
        this.dflzdm = dflzdm;
    }
    @XmlTransient
    public String getDflzmc() {
        return dflzmc;
    }

    public void setDflzmc(String dflzmc) {
        this.dflzmc = dflzmc;
    }
    @XmlAttribute(
            name = "DFQYDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqydm() {
        return dfqydm;
    }

    public void setDfqydm(String dfqydm) {
        this.dfqydm = dfqydm;
    }
    @XmlTransient
    public String getDfqymc() {
        return dfqymc;
    }

    public void setDfqymc(String dfqymc) {
        this.dfqymc = dfqymc;
    }
}

==> estateplat-common-1.2.4-20201112.060606-496-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltQlLqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltQlLq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltQlLqBdc extends QltQlLq {
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfldsyqxzdm;
    private String dfldsyqxzmc;
    private String dflzdm;
    private String dflzmc;
    private String dfqydm;
    private String dfqymc;
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFLDSYQXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfldsyqxzdm() {
        return dfldsyqxzdm;
    }

    public void setDfldsyqxzdm(String dfldsyqxzdm) {
        this.dfldsyqxzdm = dfldsyqxzdm;
    }
    @XmlAttribute(
            name = "DFLDSYQXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfldsyqxzmc() {
        return dfldsyqxzmc;
    }

    public void setDfldsyqxzmc(String dfldsyqxzmc) {
        this.dfldsyqxzmc = dfldsyqxzmc;
    }
    @XmlAttribute(
            name = "DFLZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDflzdm() {
        return dflzdm;
    }

    public void setDflzdm(String dflzdm) {
        this.dflzdm = dflzdm;
    }
    @XmlAttribute(
            name = "DFLZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDflzmc() {
        return dflzmc;
    }

    public void setDflzmc(String dflzmc) {
        this.dflzmc = dflzmc;
    }
    @XmlAttribute(
            name = "DFQYDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqydm() {
        return dfqydm;
    }

    public void setDfqydm(String dfqydm) {
        this.dfqydm = dfqydm;
    }
    @XmlAttribute(
            name = "DFQYMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqymc() {
        return dfqymc;
    }

    public void setDfqymc(String dfqymc) {
        this.dfqymc = dfqymc;
    }
}
